# tidyframe: Clean Data to Tidy Dataframe

[![travis-ci](https://travis-ci.org/Jhengsh/tidyframe.svg?branch=master)](https://travis-ci.org/Jhengsh/tidyframe)[![codecov](https://codecov.io/gh/Jhengsh/tidyframe/branch/master/graph/badge.svg)](https://codecov.io/gh/Jhengsh/tidyframe)

Overview
--------

+ Clean pandas DataFrame to tidy DataFrame
+ Inspired by [tidyr](https://github.com/tidyverse/tidyr) in R
+ Goal: Help you to create **tidy Pandas Dataframe**
+ Wapper window function from DataFrame
+ Implement R function *tidyr::gather* and *tidyr:spread* using python

Installation
------------

```sh
pip install git+https://github.com/Jhengsh/tidyframe.git
```

Tuturial
--------

+ [ipynbs](https://github.com/Jhengsh/tidyframe/tree/master/ipynbs)
